/*
 * Export a panel structure for the MIPS Creator CI20.
 *
 * Copyright (C) 2018, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/devices/lcd-jz4740-config.h>
#include <l4/devices/lcd-jz4740-panel.h>

static struct Jz4740_lcd_panel panel = {
  .config = (
      Jz4740_lcd_mode_tft_generic
    | Jz4740_lcd_bpp_24
    | Jz4740_lcd_desc_8_word
    | Jz4740_lcd_underrun_recover
    | Jz4740_lcd_ps_disabled
    | Jz4740_lcd_cls_disabled
    | Jz4740_lcd_spl_disabled
    | Jz4740_lcd_rev_disabled
    | Jz4740_lcd_pclock_negative
    | Jz4740_lcd_hsync_positive
    | Jz4740_lcd_vsync_positive
    | Jz4740_lcd_de_positive),

  // NOTE: To be configured using the HDMI DDC mechanism.

  .width = 1280,
  .height = 1024,
  .bpp = 24,
  .frame_rate = 60,
  .hsync = 112,
  .vsync = 3,
  .line_start = 248,  // back porch (blanking - hsync - offset)
  .line_end = 48,     // front porch (sync offset)
  .frame_start = 36,  // back porch (blanking - vsync - offset)
  .frame_end = 3,     // front porch (sync offset)
};

/* Employ an opaque pointer type. */

void *panel_get(void);

void *panel_get(void)
{
  return &panel;
}
